/*
+-----------------------------------------------------------------+
| MODULE NAME:                                                    |
| sgTemplate_barChartOverlay                                      |
|                                                                 |
| TYPE:                                                           |
| SAS macro code                                                  |
|                                                                 |
| DESCRIPTION:                                                    |
| Creates a StatGraph Template for overlay bar charts used in SWA42.|      
|                                                                 |
| Example:                                                        |
|                                                                 |    
|                                                                 |
| SAS VERSION:                                                    |
| SAS Version that this software unit was developed for: 9.2      |
|                                                                 |
|                                                                 |
| INPUT:                                                          |
|-----------------+-----------------------------------------------|
| Name            | Description                                   |
|-----------------+-----------------------------------------------|
|                                                                 |
| d_userTitle        | graph title                                |     
| d_userSubTitle     | graph subtitle                             |     
| d_userFootnote     | graph footnote                                  |
| d_reportVar        | reporting variable
| d_analysisVar      | analysis variable
| d_useByVar         | flag to indicate if by var is to be used
| d_byVar            | grouping/by variable
|
|
|                                                                 |
| OUTPUT:                                                         |
| This code creates a statgraph template for Text Analysis that   |
| uses overlay bar charts in the output.                          |
|                                                                 |
| CALLS:                                                          |
| NONE                                                            |
|                                                                 |
| PRECONDITIONS:                                                  |
| NONE                                                            |
|                                                                 |
| POSTCONDITIONS:                                                 |
| NONE                                                            |
|                                                                 |
| DEVELOPMENT/MAINTENANCE HISTORY:                                |
| DATE       BY      NOTE                                         |
| 21Jan2009  gunedu  Initial code                                 |
| 30Jan2009  gunedu  Removed gridded layout and handling it in    |
|                    _metag.xml                                   |
| 02Feb2009  gunedu  Changed template itemstore to usertl.templat |
| 08Jun2009  sindok  Fixed defect S0584553.                       |
| 07Aug2009  gunedu  Fixed S0600203                               |
| 10sep2013  sascis  S1007146: added conditional Data as of Date  |
| 17Feb2014  sascis  S1028357: improved Data as of Date footnote  |
+-----------------------------------------------------------------+
+-----------------------------------------------------------------+
| Copyright  2014 by SAS Institute Inc., Cary, NC 27513 USA       |
| ---All Rights Reserved.                                         |
+-----------------------------------------------------------------+
*/
proc template;

  define statgraph swagraphs.barchartoverlay/ store=usertl.templat;

	dynamic d_userTitle
		    d_userSubTitle
			d_userFootnote
			d_percentLabel
			d_clusterLabel
			d_overallLabel
			d_varLabel
			d_rolename
			col1
			col2 
			col3
			col4
			col5
			col6
			col7
			col8
			col9
			col10
			col11
			col12
			col13
			col14
			col15
			col16
			col17
			col18
			col19
			col20
			col21
			col22
			col23
			col24
			col25
			;

mvar g_showDataAsOfDateFootnote="FALSE" g_filterdate g_msgds="sashelp.wrtyanl";

begingraph;
  entrytitle d_userTitle;
  entrytitle d_userSubTitle;
  entryfootnote halign=left d_userFootnote;
  
  if ( g_showDataAsOfDateFootnote EQ "TRUE" )
        entryfootnote halign=left eval(sasmsg(g_msgds,"DATA_AS_OF_LABEL","noquote")) " " g_filterdate;
  endif;

       layout overlay / xaxisopts=(label=d_varLabel) yaxisopts=(label=d_percentLabel);      	  
			barchartparm x=value y=percent_overall / orient=vertical  DATATRANSPARENCY=0.4 LEGENDLABEL=d_overallLabel name="OALL" 
						rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7 r8=col8 r9=col9 r10=col10 r11=col11 r12=col12
						r13=col13 r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19 r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25);
        	barchartparm x=value y=percent_cluster / orient=vertical barwidth=0.5 LEGENDLABEL=d_clusterLabel name="CLUS" 
						rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7 r8=col8 r9=col9 r10=col10 r11=col11 r12=col12
						r13=col13 r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19 r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25);
			discretelegend "CLUS" "OALL" / across=2;
       endlayout;

    endgraph;

  end;
run;
