/*
+-----------------------------------------------------------------+
| MODULE NAME:                                                    |
| sgTemplate_OverlayTrend                                         |
|                                                                 |
| TYPE:                                                           |
| SAS macro code                                                  |
|                                                                 |
| DESCRIPTION:                                                    |
| Creates a StatGraph Template for overlay Line Charts used in the|
| SWA42 for Rule progration chart in Failure relation ship analysis.                                                          |
|                                                                 |
| Example:                                                        |
|                                                                 |    
|                                                                 |
| SAS VERSION:                                                    |
| SAS Version that this software unit was developed for: 9.2      |
|                                                                 |
|                                                                 |
| INPUT:                                                          |
|-----------------+-----------------------------------------------|
| Name            | Description                                   |
|-----------------+-----------------------------------------------|
|                                                                 |
| d_userTitle        | graph title                                |     
| d_userSubTitle     | graph subtitle                             |     
| d_userFootnote     | graph footnote                             |
| d_reportVar        | reporting variable                         |
| d_analysisVar      | analysis variable                          |
| d_useByVar         | flag to indicate if by var is to be used   |
| d_byVar            | grouping/by variable                       |
|                                                                 |
| OUTPUT:                                                         |
| This code creates a statgraph template for use analyses which   |
| displayes the Rule Progration Chart                            | 
|                                                                 |                                                              
| 1. Rule progration chart                                        |
|                                                                 |
| CALLS:                                                          |
| NONE                                                            |
|                                                                 |
| PRECONDITIONS:                                                  |
| NONE                                                            |
|                                                                 |
| POSTCONDITIONS:                                                 |
| NONE                                                            |
|                                                                 |
| DEVELOPMENT/MAINTENANCE HISTORY:                                |
| DATE     BY      NOTE                                           |
| 13Jul10  sinkah  Initial code for simple line chart with 2 yaxis| 
|                  Rule Progression Chart                         | 
| 10sep13  sascis  S1007146: added conditional Data as of Date    |
| 17Feb14  sascis  S1028357: improved Data as of Date footnote    |
+-----------------------------------------------------------------+
+-----------------------------------------------------------------+
| Copyright  2014 by SAS Institute Inc., Cary, NC 27513 USA       |
| ---All Rights Reserved.                                         |
+-----------------------------------------------------------------+
*/

/*
SINDOK: 10th Nov, 2008
1. This code will be executed as a part of install/config process. It will create a statgraph
template which will be stored in an item store. Currently I have designated SASHELP.tmplmst as
the item store. We will have to revisit the location part once we have a decision. parmsl can 
be a possible location.

*/



proc template;
define statgraph swagraphs.OverlayTrend/ store=usertl.templat;
dynamic d_userTitle
        d_userSubTitle
        d_userFootnote

        d_legendTitle
        d_legendType "new"

		d_xvar1
		d_yvar1
		d_xvar2
		d_yvar2
		d_markerAttrsy1
		d_markerAttrsy2
		d_xlabel
        d_ylabel
		d_ylabel2
		d_xlabel2
		d_lineattrsy1
		d_lineattrsy2
		d_display2

        col1
        col2 
        col3
        col4
        col5
        col6
        col7
        col8
        col9
        col10
        col11
        col12
        col13
        col14
        col15
        col16
        col17
        col18
        col19
        col20
        col21
        col22
        col23
        col24
        col25
		col26
        col27
        col28
        col29
        col30
        col31
        col32
        col33
        col34
        col35
		col36
        col37
        col38
        col39
        col40  
;

mvar g_displayGrid g_showDataAsOfDateFootnote="FALSE" g_filterdate g_msgds="sashelp.wrtyanl";

begingraph;
  entrytitle d_userTitle;
  entrytitle d_userSubTitle;
  entryfootnote d_userFootnote;
  
  if ( g_showDataAsOfDateFootnote EQ "TRUE" )
        entryfootnote halign=left eval(sasmsg(g_msgds,"DATA_AS_OF_LABEL","noquote")) " " g_filterdate;
  endif;
  
 
  layout overlay/     
     yaxisopts=( 
       label=d_ylabel
       griddisplay=g_displayGrid
       display=all
 
       )

	  y2axisopts=( 
       label=d_ylabel2
       griddisplay=g_displayGrid
       display=all 
	   
       )

     xaxisopts=( 
       label=d_xlabel
       griddisplay=g_displayGrid
       display=all
	   type=discrete
       
       )

      x2axisopts=( 
       label=d_xlabel2
       griddisplay=g_displayGrid
       display=all
	   type=discrete
        
       )
       ;

	seriesplot x=d_xvar1 y=d_yvar1 / name="Confidence" display=d_display2 lineattrs=d_lineattrsy1
                                  markerattrs=d_markerAttrsy1 connectorder=xaxis break=true
                   rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7
                             r8=col8 r9=col9 r10=col10 r11=col11 r12=col12 r13=col13
                             r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19
                             r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25
                             r26=col26 r27=col27 r28=col28 r29=col29 r30=col30 r31=col31
			     r32=col32 r33=col33 r34=col34 r35=col35 r36=col36 r37=col37
 			     r38=col38 r39=col39 r40=col40)
 			     
                   TIP =(x y);


    seriesplot  x=d_xvar2 y=d_yvar2 / yaxis=y2 name="Support" display=d_display2 lineattrs=d_lineattrsy2
                                  markerattrs=d_markerAttrsy2 connectorder=xaxis break=true 
               rolename= (r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7
                          r8=col8 r9=col9 r10=col10 r11=col11 r12=col12 r13=col13
                          r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19
                          r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25
						  r26=col26 r27=col27 r28=col28 r29=col29 r30=col30 r31=col31
						  r32=col32 r33=col33 r34=col34 r35=col35 r36=col36 r37=col37
 						  r38=col38 r39=col39 r40=col40)
                TIP =(X Y);
;
if (d_legendType =: "new")
   discretelegend  "Support" "Confidence" / Title=d_legendTitle; 
endif;

  endlayout;

endgraph;
end;
run;
