/*
+-----------------------------------------------------------------+
| MODULE NAME:                                                    |
| sgTemplate_SDChart                                              |
|                                                                 |
| TYPE:                                                           |
| SAS macro code                                                  |
|                                                                 |
| DESCRIPTION:                                                    |
| Creates a StatGraph Template for charts used in the SWA4.2.     |      
|                                                                 |
| Example:                                                        |
|                                                                 |    
|                                                                 |
| SAS VERSION:                                                    |
| SAS Version that this software unit was developed for: 9.2      |
|                                                                 |
|                                                                 |
| INPUT:                                                          |
|-----------------+-----------------------------------------------|
| Name            | Description                                   |
|-----------------+-----------------------------------------------|
|                                                                 |
| d_userTitle     | graph title                                   |
| d_userSubTitle  | graph subtitle                                |
| d_userFootnote  | graph footnote                                |
| d_reportVar     | reporting variable                            |
| d_analysisVar   | analysis variable                             |
| d_useByVar      | flag to indicate if by var is to be used      |
| d_byVar         | grouping/by variable                          |
|                                                                 |
| OUTPUT:                                                         |
| This code creates a statgraph template for use analyses which   | 
| use vector charts for                                           |
|                                                                 |                                                              
| 1. STATDRIVER                                                   |
|                                                                 |
| CALLS:                                                          |
| NONE                                                            |
|                                                                 |
| PRECONDITIONS:                                                  |
| NONE                                                            |
|                                                                 |
| POSTCONDITIONS:                                                 |
| NONE                                                            |
|                                                                 |
| DEVELOPMENT/MAINTENANCE HISTORY:                                |
| DATE     BY      NOTE                                           |
|                                                                 |
| 02Feb09  wehuan  created the overlay of vector charts/scatter   | 
|                  plots for STATDRIVER                           |
| 02May09  atbroo  Replacing dynamic var d_displayGrid with mvar  |
|                  g_displayGrid                                  |
| 27May09  sindok  Fixed defect S0583431. Added col13-col20.      |
| 08Jun09  sindok  Fixed defect S0584553.                         |
| 07Jul09  atbroo  Fixed defect S0590477.                         | 
| 12Jul09  atbroo  Made colors consistent with the rest of the app| 
| 10sep13  sascis  S1007146: added conditional Data as of Date    |
| 17Feb14  sascis  S1028357: improved Data as of Date footnote    |
+-----------------------------------------------------------------+
+-----------------------------------------------------------------+
| Copyright  2014 by SAS Institute Inc., Cary, NC 27513 USA       |
| ---All Rights Reserved.                                         |
+-----------------------------------------------------------------+
*/


proc template;
define statgraph swagraphs.VectorPlot/store=usertl.templat;
dynamic d_userTitle
      d_userSubTitle
      d_userFootnote
      d_vrefValue
      d_vrefLabel
      
      d_reportVar
      d_reportVarText
      
      d_analysisVarText
      
      d_lower
      d_upper
      d_actualOut
      d_actualIn
      d_baseU
      
      d_rolename
      
         col1
         col2 
         col3
         col4
         col5
         col6
         col7
         col8
         col9
         col10
         col11
         col12
         col13
         col14
         col15
         col16
         col17
         col18
         col19
         col20
         col21
         col22
         col23
         col24
         col25
      
      
      
;

mvar g_displayGrid g_showDataAsOfDateFootnote="FALSE" g_filterdate g_msgds="sashelp.wrtyanl";

begingraph;
  entrytitle d_userTitle;
  entrytitle d_userSubTitle;
  entryfootnote d_userFootnote;
  
  if ( g_showDataAsOfDateFootnote EQ "TRUE" )
        entryfootnote halign=left eval(sasmsg(g_msgds,"DATA_AS_OF_LABEL","noquote")) " " g_filterdate;
  endif;
 
  layout overlay/     
       yaxisopts=( 
       griddisplay=g_displaygrid
       display=all
       label=d_analysisVarText
       )

      xaxisopts=( 
       griddisplay=g_displaygrid 
       display=all 
       label=d_reportVarText
       )
;

       SeriesPlot x=d_reportVar y=d_lower / connectorder=xaxis
       name="lower" lineAttrs=( Pattern=2 thickness=1) 
       rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7 r8=col8 r9=col9 r10=col10 r11=col11 r12=col12
             r13=col13 r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19 r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25)      
       TIP =(X Y); 
       SeriesPlot x=d_reportVar y=d_upper /  connectorder=xaxis
       name="upper" lineAttrs=( Pattern=2 thickness=1) 
       rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7 r8=col8 r9=col9 r10=col10 r11=col11 r12=col12
             r13=col13 r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19 r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25)
       TIP =(X Y);
       ScatterPlot x=d_reportVar y=d_actualOut / markerAttrs=GraphData11
       rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7 r8=col8 r9=col9 r10=col10 r11=col11 r12=col12
              r13=col13 r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19 r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25);
       ScatterPlot x=d_reportVar y=d_actualIn / markerAttrs=GraphData1
       rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7 r8=col8 r9=col9 r10=col10 r11=col11 r12=col12
              r13=col13 r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19 r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25);

     referenceline Y = d_vrefValue / CURVELABEL=d_vrefLabel;

  endlayout; 
  endgraph;
 end;  
run; 
