/*
+-----------------------------------------------------------------+
| MODULE NAME:                                                    |
| sgTemplate_SolidDashLines                                       |
|                                                                 |
| TYPE:                                                           |
| SAS macro code                                                  |
|                                                                 |
| DESCRIPTION:                                                    |
| Creates a StatGraph Template for overlay Line Charts  with Solid|
| or dashed lines - currently, used by Teradata's Early Warning   |
| New Model (Enterprise - Projected) EI analytic                  | 
|                                                                 |
| Example:                                                        |
|                                                                 |    
|                                                                 |
| SAS VERSION:                                                    |
| SAS Version that this software unit was developed for: 9.2      |
|                                                                 |
|                                                                 |
| INPUT:                                                          |
|-----------------+-----------------------------------------------|
| Name            | Description                                   |
|-----------------+-----------------------------------------------|
|                                                                 |
| d_userTitle        | graph title                                |     
| d_userSubTitle     | graph subtitle                             |     
| d_userFootnote     | graph footnote                             |
| d_reportVar        | reporting variable                         |
| d_analysisVar      | analysis variable                          |
| d_useByVar         | flag to indicate if by var is to be used   |
| d_byVar            | grouping/by variable                       |
|                                                                 |
| OUTPUT:                                                         |
| This code creates line charts with solid or dotted lines        |
|                                                                 |
| CALLS:                                                          |
| NONE                                                            |
|                                                                 |
| PRECONDITIONS:                                                  |
| NONE                                                            |
|                                                                 |
| POSTCONDITIONS:                                                 |
| NONE                                                            |
|                                                                 |
| DEVELOPMENT/MAINTENANCE HISTORY:                                |
| DATE     BY      NOTE                                           |
| 05Jun09  atbroo  created                                        |
| 10sep13  sascis  S1007146: added conditional Data as of Date    |
| 17Feb14  sascis  S1028357: improved Data as of Date footnote    |
+-----------------------------------------------------------------+
+-----------------------------------------------------------------+
| Copyright  2014 by SAS Institute Inc., Cary, NC 27513 USA       |
| ---All Rights Reserved.                                         |
+-----------------------------------------------------------------+
*/


proc template;
define statgraph swagraphs.soliddash /store=usertl.templat;
dynamic d_userTitle
        d_userSubTitle
        d_userFootnote
        d_xlabel
        d_ylabel

        d_legendTitle
        d_legendType "plot1, plot2, all, unintialized=no legend"

        d_vrefValue
        d_vrefLabel

      /* SOLID LINES */
        d_x1
        d_y1
        d_group1 
        d_display1 "standard (line only), all (line and markers)"
        d_legendlabel1 "only used for legnedType=all"

      /* DASHED LINES */
        d_x2
        d_y2
        d_group2 
        d_display2 "standard (line only), all (line and markers)"
        d_legendlabel2 "only used for legnedType=all"

        col1
        col2 
        col3
        col4
        col5
        col6
        col7
        col8
        col9
        col10
        col11
        col12
        col13
        col14
        col15
        col16
        col17
        col18
        col19
        col20
        col21
        col22
        col23
        col24
        col25    
;

mvar g_displayGrid g_showDataAsOfDateFootnote="FALSE" g_filterdate g_msgds="sashelp.wrtyanl";

begingraph;
  entrytitle d_userTitle;
  entrytitle d_userSubTitle;
  entryfootnote halign=left d_userFootnote;
  
  if ( g_showDataAsOfDateFootnote EQ "TRUE" )
        entryfootnote halign=left eval(sasmsg(g_msgds,"DATA_AS_OF_LABEL","noquote")) " " g_filterdate;
  endif;
 
  layout overlay/     
     yaxisopts=(
       label=d_ylabel
       griddisplay=g_displayGrid
       display=all 
       )

     xaxisopts=( 
       label=d_xlabel
       griddisplay=g_displayGrid
       display=all  
       )
       ;
 
     seriesplot x=d_x1 y=d_y1 / name="plot1" legendlabel=d_legendLabel1
                                group=d_group1 display=d_display1 lineattrs=( Pattern = 1 )
                                connectorder=xaxis break=true
                rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7
                          r8=col8 r9=col9 r10=col10 r11=col11 r12=col12 r13=col13
                          r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19
                          r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25)
                TIP =(X Y);
 
     seriesplot x=d_x2 y=d_y2 / name="plot2" legendlabel=d_legendLabel2
                                group=d_group2 display=d_display2 lineattrs=( Pattern = 2 )
                                connectorder=xaxis break=true
                rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7
                          r8=col8 r9=col9 r10=col10 r11=col11 r12=col12 r13=col13
                          r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19
                          r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25)
                TIP =(X Y);
 
     referenceline Y = d_vrefValue / CURVELABEL=d_vrefLabel;

     if (d_legendType =: "all")
        discretelegend "plot1" "plot2" /Title=d_legendTitle;
     else if (d_legendType =: "plot1" )
        discretelegend "plot1" /Title=d_legendTitle;
     else if (d_legendType =: "plot2" )
        discretelegend "plot2" /Title=d_legendTitle;
     endif;
     endif;
     endif;

  endlayout;

endgraph;
end;
run;
